export declare class IdentGenerator {
    private caseInsensitive;
    lastIdent: string;
    private maxIdentCount;
    private startValue;
    returnedIdents: Array<string>;
    reservedIdents: Set<string>;
    private counters;
    private identChar;
    private increment;
    constructor(caseInsensitive?: boolean, startValue?: number, maxIdentCount?: number);
    readonly currentValue: number;
    nextIdent(): string;
    private generateNextIdent;
    /** An iterator that produces an infinite sequence of identifiers. */
    idents(): IterableIterator<string>;
    /**
     * When a generated ident is no longer in use, it should be returned
     * so it can be re-used.
     */
    returnIdent(ident: string): void;
    reserve(...idents: string[]): void;
    isReserved(ident: string): boolean;
}
interface IdentGeneratorOptions<Namespace extends string = string> {
    namespaces: Array<Namespace>;
    /**
     * Whether to use case-insensitive identifiers.
     */
    caseInsensitive?: boolean;
    /**
     * Sets the starting value. This is a standard base-10 number that is
     * converted to a corresponding identifier.
     *
     * An integer greater than or equal to 1.
     * Defaults to 1.
     */
    startValue?: number;
    /**
     * How many identifiers each ident generator should be allowed to produce.
     * Note that if any of the produced identifiers are reserved, the actual
     * number of identifiers returned will be less than the max.
     * Defaults to Infinity.
     */
    maxIdentCount?: number;
}
export declare class IdentGenerators<Namespace extends string = string> {
    namespaces: {
        [name: string]: IdentGenerator;
    };
    constructor(options: IdentGeneratorOptions<Namespace>);
    /**
     * Look up the ident generator for the given namespace. Raise an error if no
     * no such namespace exists.
     */
    get(namespace: Namespace): IdentGenerator;
    /**
     * Generate an ident from the given namespace.
     */
    nextIdent(namespace: Namespace): string;
    /**
     * Return an ident to be generated for the next requested ident.
     */
    returnIdent(namespace: Namespace, ident: string): void;
    /**
     * Reserved idents are never output by the ident generator.
     * @param namespace The namespace that ident should come from.
     * @param idents The ident that should not be generated.
     */
    reserve(namespace: Namespace, ...idents: string[]): void;
}
export {};
//# sourceMappingURL=IdentGenerator.d.ts.map